pub(super) struct NestedFormatDescription<'a, const VERSION: u8> {
pub(super) leading_whitespace: Option<Spanned<&'a str>>,
pub(super) opening_bracket: Location,
pub(super) items: Vec<Item<'a, VERSION>>,
pub(super) closing_bracket: Location,
}Available on (crate features
formatting or parsing) and crate feature alloc only.Expand description
A format description that is nested within another format description.
Fields
leading_whitespace: Option<Spanned<&'a str>>Whitespace between the end of the previous item and the opening bracket.
opening_bracket: LocationWhere the opening bracket was in the format string.
items: Vec<Item<'a, VERSION>>The items within the nested format description.
closing_bracket: LocationWhere the closing bracket was in the format string.